
Installation
=======================================
..
  :scale: 100 %
  :align: right

``nwbwidgets`` requires Python >= 3.7. The latest published version can be installed by running:

.. code-block::

    pip install nwbwidgets